clone_template

Function clone_template 

pub fn clone_template(location: &str, dest: &str) -> ProplateResult<Template>
Attemps to find a template at the given location It can be either a local path or a github repo url